@@ -3,8 +3,8 @@
 
 #include "types.h"
 
-extern const int slen1_tab[16];
-extern const int slen2_tab[16];
+extern const int shine_slen1_tab[16];
+extern const int shine_slen2_tab[16];
 
 extern const int samplerates[9];
 extern const int bitrates[16][4];
